@@ -10,7 +10,7 @@ from pathlib import Path
 from os.path import exists
 from threading import RLock
 from datetime import datetime, timedelta
-from typing import List, Optional, Tuple
+from typing import List, Optional
 from pvpower.weather_forecast import WeatherForecast
 
 
@@ -144,6 +144,7 @@ class TrainSampleLog:
             with gzip.open(compr_fn, "ab") as file:
                 line = sample.to_csv() + "\n"
                 file.write(line.encode(encoding='UTF-8'))
+            logging.debug("train record appended " + str(sample))
 
         if datetime.now() > (self.__last_compaction_time + timedelta(days=self.COMPACTION_PERIOD_DAYS)):
             self.__last_compaction_time = datetime.now()
